@@ -7,7 +7,7 @@
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 package Nile::Module::Home::Home;
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 our $AUTHORITY = 'cpan:MEWSOFT';
 
 use Nile::Module; # automatically extends Nile::Module
@@ -58,21 +58,6 @@ sub home : GET Action {
     $view->set("visitor_count", $cache->get("visitor_count"));
     #----------------------------------
 
-    $app->connect;
-    my $file = $app->file->catfile($app->var->get("log_dir"),"users.pm");
-    #my @table = $app->db->table("users")->backup($file, compress => "gzip");
-    #$app->file->gunzip("$file.gz", "$file.cgi");
-    #$app->file->zip("$file.cgi");
-    #$app->file->unzip("$file.zip");
-    #$app->dump(\@table);
-    
-    #$app->db->table("users")->copy("users_new")
-
-    #my $table = $app->db->table("users");#->clone("users1");
-    #$table->clone("users1");
-    #$table->add("count int");
-    #$table->drop("count");
-    #$app->dump($table);
     
     #----------------------------------
     return $view->out();
